/*
这里我们使用了WiFi库和ESPAsyncWebServer库，
它们用于连接WiFi网络和创建Web服务器
*/
#include <WiFi.h>               //使用WiFi库
#include <ESPAsyncWebServer.h>  //使用ESPAsyncWebServer库


//修改网络名称跟Wi-Fi密码，要跟自己电脑同一个网络
const char *ssid = "WiFi网络名称";  // 替换成您的WiFi网络名称
const char *password = "WiFi密码";  // 替换成您的WiFi密码

AsyncWebServer server(80);  //声明对象并设置端口号，一般WebServer使用80

void setup() {
  // 启动串口通信，设置通信速率为115200波特率
  Serial.begin(115200);

  // 配置WiFi模式为Station（客户端模式）
  WiFi.mode(WIFI_STA);

  // 尝试连接到WiFi网络，使用在前面定义的网络名称（ssid）和密码（password）
  WiFi.begin(ssid, password);

  // 检查WiFi连接状态，如果连接失败，则打印错误消息并返回
  if (WiFi.waitForConnectResult() != WL_CONNECTED) {
    Serial.printf("WiFi Failed!\n");
    return;
  }

  // 打印ESP32的局域网IP地址，以便在串口监视器中查看
  Serial.print("IP Address: ");
  Serial.println(WiFi.localIP());

  // 设置LED引脚为输出模式，假设LED连接到引脚21
  pinMode(21, OUTPUT);

  // 处理根路径请求，创建一个包含控制LED的按钮的HTML页面
  server.on("/", HTTP_GET, [](AsyncWebServerRequest *request) {
    String html = "<html><head><title>LED Control</title></head><body>";
    html += "<h1>Arduino Web Server</h1>";
    html += "<button id='btnOn'>Turn On LED</button>";
    html += "<button id='btnOff'>Turn Off LED</button>";
    html += "<script>";
    html += "document.getElementById('btnOn').addEventListener('click', function() {";
    html += "  var xhr = new XMLHttpRequest();";
    html += "  xhr.open('GET', '/led/on', true);";  // 发送请求以打开LED
    html += "  xhr.send();";
    html += "});";
    html += "document.getElementById('btnOff').addEventListener('click', function() {";
    html += "  var xhr = new XMLHttpRequest();";
    html += "  xhr.open('GET', '/led/off', true);";  // 发送请求以关闭LED
    html += "  xhr.send();";
    html += "});";
    html += "</script>";
    html += "</body></html>";

    // 发送HTML响应给客户端，状态码为200（OK），内容类型为text/html
    request->send(200, "text/html", html);
  });

  // 处理LED打开请求，将引脚21的电平设置为高（打开LED）
  server.on("/led/on", HTTP_GET, [](AsyncWebServerRequest *request) {
    digitalWrite(21, HIGH);  // 打开LED，假设LED连接到引脚21
    // 发送文本响应给客户端，表示LED已打开
    request->send(200, "text/plain", "LED is on");
  });

  // 处理LED关闭请求，将引脚21的电平设置为低（关闭LED）
  server.on("/led/off", HTTP_GET, [](AsyncWebServerRequest *request) {
    digitalWrite(21, LOW);  // 关闭LED，假设LED连接到引脚21
    // 发送文本响应给客户端，表示LED已关闭
    request->send(200, "text/plain", "LED is off");
  });

  // 启动Web服务器，开始监听来自客户端的请求
  server.begin();
}

void loop() {
  // 在这里可以添加其他代码，但在这个示例中，循环函数为空
}
